# Modeling: IT Components / Hosting (Meta Model v3)
### On this page
  * [The entry-level approach](https://help.sap.com/docs/leanix/ea/it-components-hosting-modeling-v3#the-entry-level-approach)
  * [The pragmatic approach](https://help.sap.com/docs/leanix/ea/it-components-hosting-modeling-v3#the-pragmatic-approach)
  * [The full-fledged approach](https://help.sap.com/docs/leanix/ea/it-components-hosting-modeling-v3#the-full-fledged-approach)
  * [Q&A](https://help.sap.com/docs/leanix/ea/it-components-hosting-modeling-v3#q&a)


Modeling Application hosting is a common challenge for all enterprise architects. While it is possible to spend years discussing the perfect model that captures every single edge case, this section provides three step-by-step guides that we recommend and that can be applied based on your needs. There is an entry-level approach, a pragmatic one as well as the full-fledged option.
